<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-sites?lang_cible=eo
// ** ne pas modifier le fichier **

return [

	// S
	'sites_description' => 'Retejoj kaj abonrilato en SPIP (privata kaj publika)',
	'sites_slogan' => 'Mastrumado de retejoj kaj de abonrilato en SPIP',
];
